@@ -1,5 +1,6 @@
 """Subpackage for assembling a lambda code package bundle for upload and deployment."""
 import os
+import typing
 import zipfile
 
 from reviser import definitions
@@ -8,7 +9,7 @@ from reviser.bundling import _installer
 
 def _create_zip(target: "definitions.Target"):
     """
-    Bundle together all of the source files into a single zip file.
+    Bundle together all source files into a single zip file.
 
     This zip file is structured so that it can be uploaded as an AWS Lambda function.
 
@@ -46,6 +47,39 @@ def _create_zip(target: "definitions.Target"):
     print(f"[ARCHIVED]: {target.bundle_zip_path}")
 
 
+def _check_do_install(
+    target: "definitions.Target",
+    reinstall: bool,
+    installed_shared_dependencies: typing.Set[str],
+):
+    """Check to see if target needs to reinstall dependencies."""
+    # Force an installation if reinstall is set and either the dependency is not
+    # shared or the dependency is shared but has not been added yet.
+    force_install = reinstall and (
+        not target.dependencies.is_shared
+        or target.dependencies.name not in installed_shared_dependencies
+    )
+
+    # Install if forced or the dependencies do net yet exist.
+    return (
+        force_install
+        or not target.dependencies.site_packages_directory.exists()
+        or not os.listdir(str(target.dependencies.site_packages_directory))
+    )
+
+
+def _check_do_copy(
+    target: "definitions.Target",
+    installed_shared_dependencies: typing.Set[str],
+):
+    """Check to see if target needs to re-copy shared dependencies."""
+    # Copy if shared and a previous installation updated the shared dependencies.
+    return (
+        target.dependencies.is_shared
+        and target.dependencies.name in installed_shared_dependencies
+    )
+
+
 def create(
     context: "definitions.Context",
     selection: "definitions.Selection",
@@ -63,21 +97,26 @@ def create(
         A selection object that defines the subset of targets to execute
         the bundling process upon.
     :param reinstall:
-        Whether or not to force re-installation of dependencies for previously
+        Whether to force re-installation of dependencies for previously
         bundled targets.
     """
     selected = context.get_selected_targets(selection)
 
+    installed_shared_dependencies: typing.Set[str] = set([])
+
     for target in selected.targets:
         target.bundle_directory.mkdir(exist_ok=True, parents=True)
 
-        skip_installs = (
-            not reinstall
-            and target.site_packages_directory.exists()
-            and os.listdir(str(target.site_packages_directory))
-        )
-        if not skip_installs:
+        if _check_do_install(target, reinstall, installed_shared_dependencies):
             _installer.install_dependencies(target)
+            if target.dependencies.is_shared and target.dependencies.name:
+                # List the shared dependency as having been installed to prevent
+                # multiple installations in the same operation.
+                installed_shared_dependencies.add(target.dependencies.name)
+        elif _check_do_copy(target, installed_shared_dependencies):
+            # Handle copying shared site packages that have already been installed by
+            # a previous target.
+            _installer.copy_shared_dependencies(target)
         else:
             print("[DEPENDENCIES]: Using existing installation cache.")
 
