@@ -1,3 +1,4 @@
+"""Commands subpackage for reviser command invcations."""
 from collections import defaultdict as _defaultdict
 
 from ..commands import aliaser
@@ -14,6 +15,7 @@ from ..commands import reloader
 from ..commands import reporter
 from ..commands import selector
 from ..commands import sheller
+from ..commands import tailer
 
 #: Commands available to the shell.
 COMMANDS = {
@@ -31,6 +33,7 @@ COMMANDS = {
     "select": selector,
     "shell": sheller,
     "status": reporter,
+    "tail": tailer,
 }
 
 #: Aliases of commands to make available to the shell.
@@ -40,7 +43,7 @@ ALIASES = {
 
 
 def _invert_aliases():
-    """Reverses the alias dictionary to be a lookup from command to aliases."""
+    """Reverse the alias dictionary to be a lookup from command to aliases."""
     out = _defaultdict(list)
     for alias, name in ALIASES.items():
         out[name].append(alias)
@@ -52,5 +55,5 @@ REVERSED_ALIASES = _invert_aliases()
 
 
 def get_module(command: str):
-    """Retrieves the command module for the associated command."""
+    """Retrieve the command module for the associated command."""
     return COMMANDS.get(ALIASES.get(command, command), None)
