@@ -1,6 +1,4 @@
-"""
-Combined single command for bundling and deploying the selected targets.
-"""
+"""Combined single command for bundling and deploying the selected targets."""
 import argparse
 import typing
 
